# Credits

Thanks to these amazing people genshin.py can be where it is now:

### Hoyo API Contributors

- [Womsxd](https://github.com/Womsxd): The author of [YuanShen User Info](https://github.com/Womsxd/YuanShen_User_Info) - a predecesor to genshinstats
- [Dimbreath](https://github.com/Dimbreath): Maintainer of [GenshinData](https://github.com/dimbreath/GenshinData), a repository of dumped client data
- [Lightczx](https://github.com/Lightczx): The author of [Snap.Genshin](https://github.com/DGP-Studio/Snap.Genshin), helped me figure out the chinese endpoints
- [lulu666lulu](https://github.com/lulu666lulu): Figured out how the chinese dynamic secret is generated
- [M-307](https://github.com/mrwan200): Worked on geetest authentication.

### Genshin.py Contributors

- [Chromosomologist](https://github.com/Chromosomologist): Helped with honkai endpoints.
- [Pokurt](https://github.com/pokurt): Helped with capturing the requests coming from the hoyolab android app.
- [GrassSand](https://github.com/grasssand) & [molehzy](https://github.com/molehzy): Provided me with working chinese cookies to test chinese endpoints.
- [Ashlen](https://github.com/thesadru): me :^)

### Feedback

- [KT](https://github.com/KT-Yeh): Developer of [原神小幫手](https://github.com/KT-Yeh/Genshin-Discord-Bot).
- [Seria](https://github.com/seriaati): Developer of [申鶴](https://github.com/seriaati/shenhe_bot).
- [Konard](https://github.com/kgirtxd): Developer of Raiden.
- [GauvraM](https://github.com/GauravM512): Translator of [原神小幫手](https://github.com/GauravM512/Genshin-Discord-Bot).
